==> paraview-5.12.1-8-x86_64.pkg.tar.zst: opt/paraview/lib/cmake/paraview/EmbossingRepresentations-vtk-module-properties.cmake <==
set(_vtk_module_import_prefix "${CMAKE_CURRENT_LIST_DIR}")
get_filename_component(_vtk_module_import_prefix "${_vtk_module_import_prefix}" DIRECTORY)
get_filename_component(_vtk_module_import_prefix "${_vtk_module_import_prefix}" DIRECTORY)
get_filename_component(_vtk_module_import_prefix "${_vtk_module_import_prefix}" DIRECTORY)
set_property(TARGET "EmbossingRepresentations::vtkEmbossingRepresentations" PROPERTY "INTERFACE_vtk_module_exclude_wrap" "FALSE")
set_property(TARGET "EmbossingRepresentations::vtkEmbossingRepresentations" PROPERTY "INTERFACE_vtk_module_depends" "ParaView::RemotingViews;VTK::RenderingOpenGL2")
set_property(TARGET "EmbossingRepresentations::vtkEmbossingRepresentations" PROPERTY "INTERFACE_vtk_module_private_depends" "VTK::CommonCore;VTK::CommonDataModel;VTK::FiltersCore;VTK::ParallelCore;VTK::RenderingCore;VTK::glew")
set_property(TARGET "EmbossingRepresentations::vtkEmbossingRepresentations" PROPERTY "INTERFACE_vtk_module_optional_depends" "")
set_property(TARGET "EmbossingRepresentations::vtkEmbossingRepresentations" PROPERTY "INTERFACE_vtk_module_implements" "")
set_property(TARGET "EmbossingRepresentations::vtkEmbossingRepresentations" PROPERTY "INTERFACE_vtk_module_implementable" "FALSE")
set_property(TARGET "EmbossingRepresentations::vtkEmbossingRepresentations" PROPERTY "INTERFACE_vtk_module_library_name" "vtkEmbossingRepresentations")
set_property(TARGET "EmbossingRepresentations::vtkEmbossingRepresentations" PROPERTY "INTERFACE_vtk_module_forward_link" "VTK::PythonUsed")
set_property(TARGET "EmbossingRepresentations::vtkEmbossingRepresentations" PROPERTY "INTERFACE_vtk_module_headers" "${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/vtkBumpMapMapper.h;${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/vtkBumpMapRepresentation.h;${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/vtkOpenGLBumpMapMapperDelegator.h;${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/vtkOpenGLExtrusionMapperDelegator.h;${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/vtkExtrusionMapper.h;${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/vtkExtrusionRepresentation.h;${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/vtkEmbossingRepresentationsModule.h")
set_property(TARGET "EmbossingRepresentations::vtkEmbossingRepresentations" PROPERTY "INTERFACE_vtk_module_hierarchy" "${_vtk_module_import_prefix}/lib/paraview/plugins/EmbossingRepresentations/vtk/hierarchy/EmbossingRepresentations/vtkEmbossingRepresentations-hierarchy.txt")
unset(_vtk_module_import_prefix)

==> paraview-5.13.1-7-x86_64.pkg.tar.zst: opt/paraview/lib/cmake/paraview/EmbossingRepresentations-vtk-module-properties.cmake <==
set(_vtk_module_import_prefix "${CMAKE_CURRENT_LIST_DIR}")
get_filename_component(_vtk_module_import_prefix "${_vtk_module_import_prefix}" DIRECTORY)
get_filename_component(_vtk_module_import_prefix "${_vtk_module_import_prefix}" DIRECTORY)
get_filename_component(_vtk_module_import_prefix "${_vtk_module_import_prefix}" DIRECTORY)
set_property(TARGET "EmbossingRepresentations::vtkEmbossingRepresentations" PROPERTY "INTERFACE_vtk_module_exclude_wrap" "FALSE")
set_property(TARGET "EmbossingRepresentations::vtkEmbossingRepresentations" PROPERTY "INTERFACE_vtk_module_include_marshal" "FALSE")
set_property(TARGET "EmbossingRepresentations::vtkEmbossingRepresentations" PROPERTY "INTERFACE_vtk_module_depends" "ParaView::RemotingViews;VTK::RenderingOpenGL2")
set_property(TARGET "EmbossingRepresentations::vtkEmbossingRepresentations" PROPERTY "INTERFACE_vtk_module_private_depends" "VTK::CommonCore;VTK::CommonDataModel;VTK::FiltersCore;VTK::ParallelCore;VTK::RenderingCore;VTK::glew")
set_property(TARGET "EmbossingRepresentations::vtkEmbossingRepresentations" PROPERTY "INTERFACE_vtk_module_optional_depends" "")
set_property(TARGET "EmbossingRepresentations::vtkEmbossingRepresentations" PROPERTY "INTERFACE_vtk_module_implements" "")
set_property(TARGET "EmbossingRepresentations::vtkEmbossingRepresentations" PROPERTY "INTERFACE_vtk_module_implementable" "FALSE")
set_property(TARGET "EmbossingRepresentations::vtkEmbossingRepresentations" PROPERTY "INTERFACE_vtk_module_library_name" "vtkEmbossingRepresentations")
set_property(TARGET "EmbossingRepresentations::vtkEmbossingRepresentations" PROPERTY "INTERFACE_vtk_module_forward_link" "VTK::PythonUsed")
set_property(TARGET "EmbossingRepresentations::vtkEmbossingRepresentations" PROPERTY "INTERFACE_vtk_module_headers" "${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/vtkBumpMapMapper.h;${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/vtkBumpMapRepresentation.h;${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/vtkOpenGLBumpMapMapperDelegator.h;${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/vtkOpenGLExtrusionMapperDelegator.h;${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/vtkExtrusionMapper.h;${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/vtkExtrusionRepresentation.h")
set_property(TARGET "EmbossingRepresentations::vtkEmbossingRepresentations" PROPERTY "INTERFACE_vtk_module_hierarchy" "${_vtk_module_import_prefix}/lib/paraview/plugins/EmbossingRepresentations/vtk/hierarchy/EmbossingRepresentations/vtkEmbossingRepresentations-hierarchy.txt")
unset(_vtk_module_import_prefix)
